Module uim.codec.parser
=======================
Parser
=======
This package contains different parsers for ink formats:

- Universal Ink Model (v3.0.0 and v3.1.0)
- Wacom Ink Layer Language (WILL)

Sub-modules
-----------
* uim.codec.parser.base
* uim.codec.parser.decoder
* uim.codec.parser.uim
* uim.codec.parser.will